nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Conen

Struct Conen 

#[repr(transparent)]
pub struct Conen(pub u32);
SCT conflict interrupt enable register

Tuple Fields

0: u32

Implementations

Source

impl Conen

pub const fn ncen(&self) -> u16

The SCT requests an interrupt when bit n of this register and the SCT conflict flag register are both one (output 0 = bit 0, output 1 = bit 1, etc.). The number of bits = number of outputs in this SCT.

pub const fn set_ncen(&mut self, val: u16)

The SCT requests an interrupt when bit n of this register and the SCT conflict flag register are both one (output 0 = bit 0, output 1 = bit 1, etc.). The number of bits = number of outputs in this SCT.