nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Conflag

Struct Conflag 

#[repr(transparent)]
pub struct Conflag(pub u32);
SCT conflict flag register

Tuple Fields

0: u32

Implementations

Source

impl Conflag

pub const fn ncflag(&self) -> u16

Bit n is one if a no-change conflict event occurred on output n since reset or a 1 was last written to this bit (output 0 = bit 0, output 1 = bit 1, etc.). The number of bits = number of outputs in this SCT.

pub const fn set_ncflag(&mut self, val: u16)

Bit n is one if a no-change conflict event occurred on output n since reset or a 1 was last written to this bit (output 0 = bit 0, output 1 = bit 1, etc.). The number of bits = number of outputs in this SCT.

pub const fn buserrl(&self) -> bool

The most recent bus error from this SCT involved writing CTR L/Unified, STATE L/Unified, MATCH L/Unified, or the Output register when the L/U counter was not halted. A word write to certain L and H registers can be half successful and half unsuccessful.

pub const fn set_buserrl(&mut self, val: bool)

The most recent bus error from this SCT involved writing CTR L/Unified, STATE L/Unified, MATCH L/Unified, or the Output register when the L/U counter was not halted. A word write to certain L and H registers can be half successful and half unsuccessful.

pub const fn buserrh(&self) -> bool

The most recent bus error from this SCT involved writing CTR H, STATE H, MATCH H, or the Output register when the H counter was not halted.

pub const fn set_buserrh(&mut self, val: bool)

The most recent bus error from this SCT involved writing CTR H, STATE H, MATCH H, or the Output register when the H counter was not halted.