#[repr(transparent)]pub struct EvState(pub u32);Expand description
SCT event state register 0
Tuple Fields
0: u32Implementations
Sourceimpl EvState
impl EvState
Sourcepub const fn statemskn(&self) -> u16
pub const fn statemskn(&self) -> u16
If bit m is one, event n happens in state m of the counter selected by the HEVENT bit (n = event number, m = state number; state 0 = bit 0, state 1= bit 1, etc.). The number of bits = number of states in this SCT.
Sourcepub const fn set_statemskn(&mut self, val: u16)
pub const fn set_statemskn(&mut self, val: u16)
If bit m is one, event n happens in state m of the counter selected by the HEVENT bit (n = event number, m = state number; state 0 = bit 0, state 1= bit 1, etc.). The number of bits = number of states in this SCT.