nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Evflag

Struct Evflag 

#[repr(transparent)]
pub struct Evflag(pub u32);
SCT event flag register

Tuple Fields

0: u32

Implementations

Source

impl Evflag

pub const fn flag(&self) -> u16

Bit n is one if event n has occurred since reset or a 1 was last written to this bit (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.

pub const fn set_flag(&mut self, val: u16)

Bit n is one if event n has occurred since reset or a 1 was last written to this bit (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.