nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Halt

Struct Halt 

#[repr(transparent)]
pub struct Halt(pub u32);
SCT halt event select register

Tuple Fields

0: u32

Implementations

Source

impl Halt

pub const fn haltmsk_l(&self) -> u16

If bit n is one, event n sets the HALT_L bit in the CTRL register (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.

pub const fn set_haltmsk_l(&mut self, val: u16)

If bit n is one, event n sets the HALT_L bit in the CTRL register (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.

pub const fn haltmsk_h(&self) -> u16

If bit n is one, event n sets the HALT_H bit in the CTRL register (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.

pub const fn set_haltmsk_h(&mut self, val: u16)

If bit n is one, event n sets the HALT_H bit in the CTRL register (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.