nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Limit

Struct Limit 

#[repr(transparent)]
pub struct Limit(pub u32);
SCT limit event select register

Tuple Fields

0: u32

Implementations

Source

impl Limit

pub const fn limmsk_l(&self) -> u16

If bit n is one, event n is used as a counter limit for the L or unified counter (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.

pub const fn set_limmsk_l(&mut self, val: u16)

If bit n is one, event n is used as a counter limit for the L or unified counter (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.

pub const fn limmsk_h(&self) -> u16

If bit n is one, event n is used as a counter limit for the H counter (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.

pub const fn set_limmsk_h(&mut self, val: u16)

If bit n is one, event n is used as a counter limit for the H counter (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.