nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Res

Struct Res 

#[repr(transparent)]
pub struct Res(pub u32);
SCT conflict resolution register

Tuple Fields

0: u32

Implementations

Source

impl Res

pub const fn ores(&self, n: usize) -> Ores

Effect of simultaneous set and clear on output 0.

pub const fn set_ores(&mut self, n: usize, val: Ores)

Effect of simultaneous set and clear on output 0.