nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Start

Struct Start 

#[repr(transparent)]
pub struct Start(pub u32);
SCT start event select register

Tuple Fields

0: u32

Implementations

Source

impl Start

pub const fn startmsk_l(&self) -> u16

If bit n is one, event n clears the STOP_L bit in the CTRL register (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.

pub const fn set_startmsk_l(&mut self, val: u16)

If bit n is one, event n clears the STOP_L bit in the CTRL register (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.

pub const fn startmsk_h(&self) -> u16

If bit n is one, event n clears the STOP_H bit in the CTRL register (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.

pub const fn set_startmsk_h(&mut self, val: u16)

If bit n is one, event n clears the STOP_H bit in the CTRL register (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.