nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Stop

Struct Stop 

#[repr(transparent)]
pub struct Stop(pub u32);
SCT stop event select register

Tuple Fields

0: u32

Implementations

Source

impl Stop

pub const fn stopmsk_l(&self) -> u16

If bit n is one, event n sets the STOP_L bit in the CTRL register (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.

pub const fn set_stopmsk_l(&mut self, val: u16)

If bit n is one, event n sets the STOP_L bit in the CTRL register (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.

pub const fn stopmsk_h(&self) -> u16

If bit n is one, event n sets the STOP_H bit in the CTRL register (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.

pub const fn set_stopmsk_h(&mut self, val: u16)

If bit n is one, event n sets the STOP_H bit in the CTRL register (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.