#[repr(transparent)]pub struct Conflag(pub u32);Expand description
SCT conflict flag register
Tuple Fields
0: u32Implementations
Sourceimpl Conflag
impl Conflag
Sourcepub const fn ncflag(&self) -> u16
pub const fn ncflag(&self) -> u16
Bit n is one if a no-change conflict event occurred on output n since reset or a 1 was last written to this bit (output 0 = bit 0, output 1 = bit 1, etc.). The number of bits = number of outputs in this SCT.
Sourcepub const fn set_ncflag(&mut self, val: u16)
pub const fn set_ncflag(&mut self, val: u16)
Bit n is one if a no-change conflict event occurred on output n since reset or a 1 was last written to this bit (output 0 = bit 0, output 1 = bit 1, etc.). The number of bits = number of outputs in this SCT.
Sourcepub const fn buserrl(&self) -> bool
pub const fn buserrl(&self) -> bool
The most recent bus error from this SCT involved writing CTR L/Unified, STATE L/Unified, MATCH L/Unified, or the Output register when the L/U counter was not halted. A word write to certain L and H registers can be half successful and half unsuccessful.
Sourcepub const fn set_buserrl(&mut self, val: bool)
pub const fn set_buserrl(&mut self, val: bool)
The most recent bus error from this SCT involved writing CTR L/Unified, STATE L/Unified, MATCH L/Unified, or the Output register when the L/U counter was not halted. A word write to certain L and H registers can be half successful and half unsuccessful.
Sourcepub const fn buserrh(&self) -> bool
pub const fn buserrh(&self) -> bool
The most recent bus error from this SCT involved writing CTR H, STATE H, MATCH H, or the Output register when the H counter was not halted.
Sourcepub const fn set_buserrh(&mut self, val: bool)
pub const fn set_buserrh(&mut self, val: bool)
The most recent bus error from this SCT involved writing CTR H, STATE H, MATCH H, or the Output register when the H counter was not halted.