#[repr(transparent)]pub struct Start(pub u32);Expand description
SCT start event select register
Tuple Fields
0: u32Implementations
Sourceimpl Start
impl Start
Sourcepub const fn startmsk_l(&self) -> u16
pub const fn startmsk_l(&self) -> u16
If bit n is one, event n clears the STOP_L bit in the CTRL register (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.
Sourcepub const fn set_startmsk_l(&mut self, val: u16)
pub const fn set_startmsk_l(&mut self, val: u16)
If bit n is one, event n clears the STOP_L bit in the CTRL register (event 0 = bit 0, event 1 = bit 1, etc.). The number of bits = number of events in this SCT.
Sourcepub const fn startmsk_h(&self) -> u16
pub const fn startmsk_h(&self) -> u16
If bit n is one, event n clears the STOP_H bit in the CTRL register (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.
Sourcepub const fn set_startmsk_h(&mut self, val: u16)
pub const fn set_startmsk_h(&mut self, val: u16)
If bit n is one, event n clears the STOP_H bit in the CTRL register (event 0 = bit 16, event 1 = bit 17, etc.). The number of bits = number of events in this SCT.